@@ -29,11 +29,13 @@ public:
     explicit UserManager(QObject *parent = 0);
     virtual ~UserManager();
     QList<UserEntry> users();
-    uint addUser(const QString &userName);
+    uint addUser(const QString &userLogin);
+    uint addUserWithParam(const QString &userLogin, const QString &userName, uint quota);
     bool removeUser(uint uid);
     uint currentUser();
     QString currentUserUuid();
     bool setCurrentUser(uint uid);
+    bool setNextSessionUser(uint uid);
     bool modifyUser(uint uid, const QString &newFullName);
 
     QString userUuid(uint uid);
